/*This .do file is a minor modification of a .do file from  Bitler, Gelbach, 
and Hoynes (2017) "Can Variation in Subgroups' Average Treatment Effects 
Explain Treatment Effect Heterogeneity? Evidence from a Social Experiment" 
that generates Table 2 in their paper. The original .do file is licensed
under BSD-3 license (see LICENSE.txt for details). Interested parties can 
get the original code in Bitler, Gelbach, and Hoynes's (2017) replication 
file in directory "dofiles/bgh_table2.do" */		  

*******************************
clear
clear matrix
set mem 6500m

use $procdata/data-final.dta, clear
keep if quarter >=1 & quarter<=7
cap gen byte fullsample = 1

set seed 10203

local racevars "white black hisp othmsrac"
local edvars   "gtehsged nohsged misshsged"
local ykidvars "ykidlt6 ykidge6 missykidlt6"
local whvars   "anyadcpq7 noadcpq7"
local ehvars   "anyernpq7 noernpq7"
local mhvars   "martogapt marnvr missmarnvr"
local nkvars   "kidctlt2 kidctge2 misskidctgt2"
local allvars  "fullsample"
local pq7evars  "ernpq7hi ernpq7lo vernpq70"
local npqevars "npqern0 npqernlo npqernhi"

egen race = group(`racevars')
egen ed   = group(`edvars')
egen ykid = group(`ykidvars')
egen eh = group(`ehvars')
egen wh = group(`whvars')
egen mh = group(`mhvars')
egen nk = group(`nkvars')
egen all = group(`allvars')
egen pq7e = group(`pq7evars')
egen npqe = group(`npqevars')

global list "pq7e npqe ed wh ykid mh"
global sglist "$list"
forvalues i=1/7 {
	local iplus1 = `i'+1
	local var1 : word `i' of $list

	forvalues j=`iplus1'/7 {
		local var2 : word `j' of $list
		*di "var1 var2 = '`var1' `var2''"
		egen `var1'_`var2' = group(``var1'vars' ``var2'vars')
		global sglist "$sglist `var1'_`var2'"
	}
}

**** Add in all at front
global sglist "all $sglist race"
qui di "$sglist"

*************************************************************
**** Next chunk of code to collapse really small cells    ***
*************************************************************
**** Pool missing one and missing the other kids all together
capture tab mh_nk
capture recode mh_nk (2=1) (3=1) (4=2) (5=3) (6=4) (7=5)
capture tab mh_nk

**** missmarnvr most likely missing ykid too
*** combine all with missmarnvr==1 (some of missykid)
capture tab ykid_mh
capture recode ykid_mh (2=1) (3=2) (4=3) (5=1) (6=4) (7=5)
capture tab ykid_mh

**** Fix small cells for ed_mh
**** collapse all missings
capture tab ed_mh
capture recode ed_mh (2=1) (3=1) (4=1) (7=1) (5=2) (6=3) (8=4) (9=5)
capture tab ed_mh

**** Fix small cells for npqe_ykid
**** collapse all missings for ykid
capture tab npqe_ykid
capture recode npqe_ykid (4=1) (7=1) (5=4) (6=5) (8=6) (9=7)
capture tab npqe_ykid

**** Fix small cells for wpq7lev_ed
*** cells 2 5 7
*** 2 is pwagpq7hi and nohsged 9 people
*** 5 is pwagpq7lo and nohsged 18 people
*** 7 is pwagpq70 and misshsged 5 people
*** combine the pwagepq7 and nohsged 2 and 5 with other nohsged 8
*** combine misshsged and pwagpq70 7 with missgsged & pwagpq7lo 4
capture tab wpq7lev_ed
capture recode wpq7lev_ed (5=2) (8=2) (7=4) (6=5) (9=6) 
capture tab wpq7lev_ed

**** Fix small cells for wpq7lev_mh
*** cells 1 4 7 missing married, and low, med hi
*** 1 is low and missing, 4 is med and misisng, 7 is hi and missing
*** collapse 4 and 7 (missing hi with missing medium)
capture tab wpq7lev_mh
capture recode wpq7lev_mh (7=4) (8=7) (9=8)
cap tab wpq7lev_mh

*************************************************************
**** End of code to collapse really small cells           ***
*************************************************************
** Show sglist
de $sglist

** Tab cells
for any $sglist: tab X if quarter == 1

*************************************************************
**** Create a small data set to pull in
*** only keep data and quarters we need
keep $sglist ernq quarter e
keep if quarter>=1 & quarter<=7
save $procdata/pre-processed.dta, replace