# A function to report p-values for a given covariate X
# ------------------------------------ #
# Author: Mauricio Olivares
# LMU Munich
# ------------------------------------ #

report.pvalues <- function(fake){
  # ------------------------------- #
  # fake: array of dimension k,2,q
  #       of p-values for a given 
  #       covariate X, where k is the
  #       number of levels of X and
  #       q is the number of quarters
  #       The second dimension refers
  #       to the p-value and the rate
  #       of NAs from the test.
  # Returns a list of three vectors. 
  # 1) Raw p-values
  # 2) Bonferroni-adjusted p-values
  # 3) Holm-adjusted p-values
  # ------------------------------- #
  
  vectorize.it <- as.vector(fake[,1,])
  remove.nas <- vectorize.it[!(is.na(vectorize.it))]
  order.pval <- remove.nas[order(remove.nas)]
  
  # Export results
  object_results<-list()
  object_results$raw <- order.pval
  object_results$order <- order(remove.nas)
  object_results$bonferroni <- p.adjust(order.pval,method = "bonferroni")
  object_results$holm <- p.adjust(order.pval,method = "holm")
  
  output.names <- c("Raw p-values","Underlying Order","Bonferroni p-values","Holm p-values")
  names(object_results) <- output.names
  return(object_results) 
}